// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef IMPORTWIZARD_VERSION_H
#define IMPORTWIZARD_VERSION_H

#define IMPORTWIZARD_VERSION_STRING "6.7.90"
#define IMPORTWIZARD_VERSION_MAJOR 6
#define IMPORTWIZARD_VERSION_MINOR 7
#define IMPORTWIZARD_VERSION_PATCH 90
#define IMPORTWIZARD_VERSION ((6<<16)|(7<<8)|(90))

#endif
